Authors
=======

Authors ordered by first contribution.

  * [Liam Cooke](https://github.com/araile)
  * [Baishampayan Ghose](http://github.com/ghoseb)
  * [Jeremy Dunck](http://github.com/jdunck)
  * Gabriel Genellina
  * [Eduardo de Oliveira Padoan](http://github.com/edcrypt)
  * [Guff](http://github.com/Guff)
  * [Bob Farrell](http://github.com/bobf)
  * [Ed Page](http://github.com/epage)
  * Charlie Nolan
  * [Steve Losh](https://github.com/sjl)
  * [Adam Lloyd](https://github.com/alloy-d)
  * [Andrei Fokau](https://github.com/andreif)
  * [Frederic De Groef](https://github.com/sevas)
